pub struct DMSCRedisQueue { /* private fields */ }Expand description
Redis queue implementation for the DMSC queue system.
This struct provides a Redis implementation of the DMSCQueue trait, allowing sending and receiving messages using Redis lists as the underlying message broker.
Implementations
Sourceimpl DMSCRedisQueue
impl DMSCRedisQueue
Sourcepub async fn new(name: &str, connection_string: &str) -> DMSCResult<Self>
pub async fn new(name: &str, connection_string: &str) -> DMSCResult<Self>
Sourcepub fn new_with_client(name: &str, client: Client) -> DMSCResult<Self>
pub fn new_with_client(name: &str, client: Client) -> DMSCResult<Self>
Sourcepub async fn new_with_connection(
name: &str,
connection_string: &str,
) -> DMSCResult<Self>
pub async fn new_with_connection( name: &str, connection_string: &str, ) -> DMSCResult<Self>